{% extends "base.html" %}

{% block content %}
    <div class="container">
        <div class="row">
            <div class="col-lg-12">
                <span>{{ service.title }}</span>
                <p>{{ service.description }}</p>
                <img class="img-fluid" src="{{ service.image.url }}" alt="{{ service.title }}">
            </div>
        </div>
    </div>
{% endblock content %}
